/*
Copyright 2019 Dr. Thomas Benjamin Senior, Michael Zoeller 

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System.Collections;
using System.Collections.Generic;
using UnityEngine;

namespace EyeSkills
{
    /// <summary>
    /// EyeSkills Audio Manager.  Simplifies the loading and playing of pre-generated audio resources.
    /// </summary>
    public class AudioManager : MonoBehaviour
    {
        public string language = "en";
        public string ttsAudioDir = "Audio";

        AudioSource audioSource;
        AudioClip notFoundClip;

        void Start()
        {
            DontDestroyOnLoad(this.gameObject);
        }

        // singleton like access pattern
        public static AudioManager instance = null;

        void Awake()
        {
            audioSource = GetComponent<AudioSource>();
            notFoundClip = Resources.Load(ttsAudioDir + "/DoesNotExist") as AudioClip;

            if (instance == null)
                instance = this;
            else if (instance != this)
                Destroy(gameObject);
        }

        public void Say(string key)
        {
            string audioFile = ttsAudioDir + "/" + language + "-" + key;
            //string audioFile = ttsAudioDir + "/" + key;
            //Debug.Log("Looking for " + audioFile);

            AudioClip clip = null;
            try
            {
                clip = Resources.Load<AudioClip>(audioFile);
            }
            catch (UnityException e)
            {
                Debug.LogWarning(e);
            }

            if (clip == null)
                audioSource.clip = notFoundClip;
            else
                audioSource.clip = clip;

            audioSource.Play();
        }
    }
}