/*
Copyright 2019 Dr. Thomas Benjamin Senior, Michael Zoeller

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
using UnityEngine;

namespace EyeSkills.ImageEffects
{
    [ExecuteInEditMode]
    public class Brightness : ImageEffectBase
    {
        [Range(0f, 1.0f)] public float brightness = 1f;
        private float a = 1f / 100f;

        // Modifies the rate of darkening
        public float rangeSensitivity = 1.2f;

        // Called by camera to apply image effect
        void OnRenderImage(RenderTexture source, RenderTexture destination)
        {
            //Brightness of 0 is full brightness. 1 should be dark.
            float adaptedBrightness = Mathf.Pow(a, brightness*rangeSensitivity); // Make the drop off towards black far slower.
            material.SetFloat("_Brightness", adaptedBrightness);
            Graphics.Blit(source, destination, material);
        }
    }
}
