﻿/*
Copyright 2019 Dr. Thomas Benjamin Senior, Michael Zoeller

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System.Collections;
using System.Collections.Generic;
using UnityEngine;

/// <summary>
/// Selection indicator scaler. Given a game object to represent an indicator, we are told what percentage we ought to display.
/// </summary>
public class SelectionIndicatorScaler : MonoBehaviour {

    public GameObject indicatorLeft,indicatorRight;
    public float maxScale = 20f; 
    private float initialXPositionLeft = 0f, initialXPositionRight = 0f;
	// Use this for initialization
	void Start () {
        initialXPositionLeft = indicatorLeft.transform.localPosition.x;
        Debug.Log("Original Stillness indicator left position " + initialXPositionLeft);
        initialXPositionRight = indicatorRight.transform.localPosition.x;
        Debug.Log("Original Stillness indicator right position " + initialXPositionRight);
        indicatorLeft.SetActive(true);
        indicatorRight.SetActive(true);
    }
	
    /// <summary>
    /// Sets the percentage displayed by the indicator. From 0 to 1.
    /// </summary>
    /// <param name="percentage">Percentage.</param>
    public void SetIndicatorPercentage(float percentage){
        //Debug.Log("Setting maxScale " + maxScale + " multiplied by "+ percentage);
        //indicator.transform.localScale = new Vector3(maxScale * percentage,1,1);

        indicatorLeft.transform.localPosition = new Vector3( (initialXPositionLeft + (maxScale * percentage)), indicatorLeft.transform.localPosition.y,indicatorLeft.transform.localPosition.z);
        indicatorRight.transform.localPosition = new Vector3((initialXPositionRight + (maxScale * percentage)), indicatorRight.transform.localPosition.y, indicatorRight.transform.localPosition.z);
    }

    public void Reset()
    {
        indicatorLeft.transform.localPosition = new Vector3(initialXPositionLeft, indicatorLeft.transform.localPosition.y, indicatorLeft.transform.localPosition.z);
        indicatorRight.transform.localPosition = new Vector3(initialXPositionRight, indicatorRight.transform.localPosition.y, indicatorRight.transform.localPosition.z);
    }

    /// <summary>
    /// Shows the selected state
    /// </summary>
    public void ShowSelected(){

    }
}
